==> esp8266-0.3.0.crate: esp8266-0.3.0/src/i2s/i2sconf_sigle_data.rs <==
#[doc = "Register `I2SCONF_SIGLE_DATA` reader"]
pub struct R(crate::R<I2SCONF_SIGLE_DATA_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<I2SCONF_SIGLE_DATA_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::convert::From<crate::R<I2SCONF_SIGLE_DATA_SPEC>> for R {
    fn from(reader: crate::R<I2SCONF_SIGLE_DATA_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `I2SCONF_SIGLE_DATA` writer"]
pub struct W(crate::W<I2SCONF_SIGLE_DATA_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<I2SCONF_SIGLE_DATA_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl core::convert::From<crate::W<I2SCONF_SIGLE_DATA_SPEC>> for W {
    fn from(writer: crate::W<I2SCONF_SIGLE_DATA_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `I2S_I2S_SIGLE_DATA` reader - "]
pub struct I2S_I2S_SIGLE_DATA_R(crate::FieldReader<u32, u32>);
impl I2S_I2S_SIGLE_DATA_R {
    pub(crate) fn new(bits: u32) -> Self {
        I2S_I2S_SIGLE_DATA_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for I2S_I2S_SIGLE_DATA_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `I2S_I2S_SIGLE_DATA` writer - "]
pub struct I2S_I2S_SIGLE_DATA_W<'a> {
    w: &'a mut W,
}
impl<'a> I2S_I2S_SIGLE_DATA_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xffff_ffff) | ((value as u32) & 0xffff_ffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31"]
    #[inline(always)]
    pub fn i2s_i2s_sigle_data(&self) -> I2S_I2S_SIGLE_DATA_R {
        I2S_I2S_SIGLE_DATA_R::new((self.bits & 0xffff_ffff) as u32)
    }
}
impl W {
    #[doc = "Bits 0:31"]
    #[inline(always)]
    pub fn i2s_i2s_sigle_data(&mut self) -> I2S_I2S_SIGLE_DATA_W {
        I2S_I2S_SIGLE_DATA_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "I2SCONF_SIGLE_DATA\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [i2sconf_sigle_data](index.html) module"]
pub struct I2SCONF_SIGLE_DATA_SPEC;
impl crate::RegisterSpec for I2SCONF_SIGLE_DATA_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [i2sconf_sigle_data::R](R) reader structure"]
impl crate::Readable for I2SCONF_SIGLE_DATA_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [i2sconf_sigle_data::W](W) writer structure"]
impl crate::Writable for I2SCONF_SIGLE_DATA_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets I2SCONF_SIGLE_DATA to value 0"]
impl crate::Resettable for I2SCONF_SIGLE_DATA_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp8266-0.4.0.crate: esp8266-0.4.0/src/i2s/i2sconf_sigle_data.rs <==
#[doc = "Register `I2SCONF_SIGLE_DATA` reader"]
pub struct R(crate::R<I2SCONF_SIGLE_DATA_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<I2SCONF_SIGLE_DATA_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<I2SCONF_SIGLE_DATA_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<I2SCONF_SIGLE_DATA_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `I2SCONF_SIGLE_DATA` writer"]
pub struct W(crate::W<I2SCONF_SIGLE_DATA_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<I2SCONF_SIGLE_DATA_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<I2SCONF_SIGLE_DATA_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<I2SCONF_SIGLE_DATA_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `I2S_I2S_SIGLE_DATA` reader - "]
pub struct I2S_I2S_SIGLE_DATA_R(crate::FieldReader<u32, u32>);
impl I2S_I2S_SIGLE_DATA_R {
    #[inline(always)]
    pub(crate) fn new(bits: u32) -> Self {
        I2S_I2S_SIGLE_DATA_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for I2S_I2S_SIGLE_DATA_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `I2S_I2S_SIGLE_DATA` writer - "]
pub struct I2S_I2S_SIGLE_DATA_W<'a> {
    w: &'a mut W,
}
impl<'a> I2S_I2S_SIGLE_DATA_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = value as u32;
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31"]
    #[inline(always)]
    pub fn i2s_i2s_sigle_data(&self) -> I2S_I2S_SIGLE_DATA_R {
        I2S_I2S_SIGLE_DATA_R::new(self.bits as u32)
    }
}
impl W {
    #[doc = "Bits 0:31"]
    #[inline(always)]
    pub fn i2s_i2s_sigle_data(&mut self) -> I2S_I2S_SIGLE_DATA_W {
        I2S_I2S_SIGLE_DATA_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "I2SCONF_SIGLE_DATA\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [i2sconf_sigle_data](index.html) module"]
pub struct I2SCONF_SIGLE_DATA_SPEC;
impl crate::RegisterSpec for I2SCONF_SIGLE_DATA_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [i2sconf_sigle_data::R](R) reader structure"]
impl crate::Readable for I2SCONF_SIGLE_DATA_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [i2sconf_sigle_data::W](W) writer structure"]
impl crate::Writable for I2SCONF_SIGLE_DATA_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets I2SCONF_SIGLE_DATA to value 0"]
impl crate::Resettable for I2SCONF_SIGLE_DATA_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
